MCP Tools
=========

Tool implementations for each MCP operation exposed by the server.

.. automodule:: mousetail.mcp.tools
   :members:
   :undoc-members:
   :show-inheritance:

Tool Functions
--------------

Collection Tools
~~~~~~~~~~~~~~~~

.. autofunction:: mousetail.mcp.tools.list_collections_tool

.. autofunction:: mousetail.mcp.tools.get_collection_info_tool

Deck Tools
~~~~~~~~~~

.. autofunction:: mousetail.mcp.tools.list_decks_tool

.. autofunction:: mousetail.mcp.tools.create_deck_tool

Note Type Tools
~~~~~~~~~~~~~~~

.. autofunction:: mousetail.mcp.tools.list_note_types_tool

Note Tools
~~~~~~~~~~

.. autofunction:: mousetail.mcp.tools.create_note_tool

.. autofunction:: mousetail.mcp.tools.search_notes_tool

.. autofunction:: mousetail.mcp.tools.get_note_tool

.. autofunction:: mousetail.mcp.tools.update_note_tool
